//css_ref System.Data;
//css_ref System.Transactions;
//css_ref System.Xml.dll;
//css_ref Interop.SAPbobsCOM.dll;
//css_ref log4net.dll;
//css_ref Produmex.Foundation.Data.dll;
//css_ref Produmex.Foundation.Data.Sbo.dll;
//css_ref Produmex.Foundation.dll;
//css_ref Produmex.Foundation.Sbo.dll;
//css_ref Produmex.Sbo.Logex.Data.dll;
//css_ref Produmex.Sbo.Logex.Lino.dll;

using System;
using System.Transactions;
using Produmex.Foundation.Data.Sbo;
using Produmex.Foundation.Data.Sbo.Attributes;
using Produmex.Foundation.Data.Sbo.BusinessObjects;
using Produmex.Foundation.Data.Sbo.BusinessObjects.Convertors;
using Produmex.Foundation.Data.Sbo.BusinessObjects.Definitions;
using Produmex.Foundation.Data.Sbo.Providers;
using Produmex.Foundation.Reflection;
using Produmex.Sbo.Logex.Data.BusinessObjects;
using Produmex.Sbo.Logex.Data.BusinessObjects.Definitions;
using Produmex.Sbo.Logex.Data.Providers;

namespace AddWorkflows
{
    class Program
    {
        const string CONNECTION_STRING = "Server=localhost;CompanyDB=SBODemo_US;UseTrusted=False;DbUserName=sa;DbPassword=B1Admin;UserName=manager;Password=manager;Pooling=True;MinPoolSize=2;MaxPoolSize=10;ServerType=MSSQL2005;DBCultureInfo=en-US;LicenseServer=localhost:30000;ExtraDb=PMX_SBODemo_US";
        //const string CONNECTION_STRING = "Server=localhost;CompanyDB=IMPERMO_BE_IMPORT;UseTrusted=False;DbUserName=sa;DbPassword=dihbwwei963;UserName=manager;Password=produmex;Pooling=True;MinPoolSize=2;MaxPoolSize=10;ServerType=MSSQL2008;DBCultureInfo=en-US;LicenseServer=localhost:30000;ExtraDb=PMX_IMPERMO_BE_IMPORT";
        const string SCRIPT_ROOT = @"..\WorkflowScripts";

        static void Main(string[] args)
        {
            using (TransactionScope scope = PmxDbConnection.GetNewTransactionScope())
            {
                using (PmxDbConnectionSql dbConn = new PmxDbConnectionSql(CONNECTION_STRING))
                {
                    dbConn.Open(); //Open connection to SAP
                    Console.WriteLine("Connection is open to database");

                    AddUpdateWorkflowScript(PmxWorkflowExecutionTypes.SUB_FLOW, "ImpermoCountLogisticUnitsScript",
                        SCRIPT_ROOT + @"\WorkflowScript_ImpermoCountLogisticUnitsScript\WorkflowScript_ImpermoCountLogisticUnitsScript.cs", dbConn);

                    AddUpdateWorkflowScript(PmxWorkflowExecutionTypes.SUB_FLOW, "ImpermoScanSSCCOnLocationScript",
                        SCRIPT_ROOT + @"\WorkflowScript_ImpermoScanSSCCOnLocationScript\WorkflowScript_ImpermoScanSSCCOnLocationScript.cs", dbConn);
                }

                //Complete transaction
                scope.Complete();
                Console.WriteLine("Done with workflow ...");
            }


        }


        /// <summary>
        /// Add/Update script workflow
        /// </summary>
        /// <param name="executionType">Type of the execution.</param>
        /// <param name="name">The name of the flow.</param>
        /// <param name="sourceFilePath">Name of the file.</param>
        /// <param name="sqlConn">The SQL conn.</param>
        private static void AddUpdateWorkflowScript(string executionType, string name, string sourceFilePath, PmxDbConnectionSql sqlConn)
        {
            PmxWorkflowProvider wfProvider = new PmxWorkflowProvider(sqlConn);
            PmxWorkflow workflow = wfProvider.GetWorkflowByName(name);
            PmxWorkflowScriptProvider wfscProvider = new PmxWorkflowScriptProvider(sqlConn);
            PmxWorkflowScript bo = null;
            if (workflow == null)
            {
                //add the workflow
                bo = wfscProvider.GetNewBO();
                bo.Name = name;
                wfscProvider.AddBO(bo);
            }
            else
            {
                if (workflow.ObjType == Produmex.Sbo.Logex.Data.BusinessObjects.Definitions.PmxObjectTypes.PmxWorkflowScript)
                {
                    bo = wfscProvider.GetBO(workflow.InternalKey);

                }
            }

            if (bo != null)
            {
                bo.ExecutionType = executionType;

                wfscProvider.UpdateSourceFromFileAndCompile(bo, sourceFilePath, sqlConn);
            }



        }
    }
}
